@@ -5,47 +5,29 @@
 
 use serde_json::Value;
 
-/// `content` module contains the content providers for files and http/https
-#[cfg(feature = "code")]
-mod content;
+use crate::errors::*;
 
 /// A set of serializers to read flow models from various text formats based on file extension
-#[cfg(feature = "code")]
 pub mod deserializers;
 
 /// We'll put our errors in an `errors` module, and other modules in this crate will `use errors::*;`
 /// to get access to everything `error_chain` creates.
-#[cfg(feature = "code")]
 pub mod errors;
 
-/// `flow_manifest` is the struct that specifies the manifest of functions in a flow
-#[cfg(feature = "code")]
-pub mod flow_manifest;
-
-/// `function` defines functions that form part of a flow
-#[cfg(feature = "code")]
-pub mod function;
-
-/// `input` defines the struct for inputs to functions in a flow
-#[cfg(feature = "code")]
-pub mod input;
-
-/// `lib_manifest` defines the structs for specifying a Library's manifest and methods to load it
-#[cfg(feature = "code")]
-pub mod lib_manifest;
-
-/// `lib_provider` is used to resolve library references of the type "lib://" using lib search path
-#[cfg(feature = "code")]
-pub mod lib_provider;
-
-/// `output_connection` defines a struct for a function's output connection
-#[cfg(feature = "code")]
-pub mod output_connection;
+/// `model` module defines a number of core data structures
+pub mod model;
 
 /// Utility functions related to Urls
-#[cfg(feature = "code")]
 pub mod url_helper;
 
+/// `content` module contains the content providers for files and http/https
+#[cfg(not(target_arch = "wasm32"))]
+mod content;
+
+/// `lib_provider` is used to resolve library references of the type "lib://" using lib search path
+#[cfg(not(target_arch = "wasm32"))]
+pub mod lib_provider;
+
 /// Implementations should return a value of type `RunAgain` to indicate if it should be
 /// executed more times in the future.
 pub type RunAgain = bool;
@@ -65,6 +47,7 @@ pub const DONT_RUN_AGAIN: RunAgain = false;
 ///
 /// ```
 /// use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+/// use flowcore::errors::Result;
 /// use serde_json::Value;
 /// use serde_json::json;
 ///
@@ -75,7 +58,7 @@ pub const DONT_RUN_AGAIN: RunAgain = false;
 ///     A compare implementation that takes two numbers and outputs the comparisons between them
 /// */
 /// impl Implementation for Compare {
-///     fn run(&self, mut inputs: &[Value]) -> (Option<Value>, RunAgain) {
+///     fn run(&self, mut inputs: &[Value]) -> Result<(Option<Value>, RunAgain)> {
 ///         let left = inputs[0].as_i64().unwrap();
 ///         let right = inputs[1].as_i64().unwrap();
 ///
@@ -87,11 +70,15 @@ pub const DONT_RUN_AGAIN: RunAgain = false;
 ///                     "gte" : left >= right
 ///                 });
 ///
-///         (None, RUN_AGAIN)
+///         Ok((None, RUN_AGAIN))
 ///     }
 /// }
 /// ```
+///
+/// **Note**: It is recommended to implement this by using the `flow_function` macro from the
+/// `flow_macro` crate to simplify input gathering and to hide the boiler plate code around the
+/// function implementing the logic.
 pub trait Implementation: Sync + Send {
     /// The `run` method is used to execute the implementation
-    fn run(&self, inputs: &[Value]) -> (Option<Value>, RunAgain);
+    fn run(&self, inputs: &[Value]) -> Result<(Option<Value>, RunAgain)>;
 }
